@@ -72,9 +72,9 @@ void gcgm_DMH_bdmcmc_ma( int *iter, int *burnin, int G[], double g_prior[], doub
 	for( j = 1; j < dim; j++ )
 	    for( i = 0; i < j; i++ )
 	    {
-	        ij = g_prior[ j * dim + i ];
-	        if( ( ij != 0.0 ) or ( ij != 1.0 ) )
-	        {
+  	      ij = j * dim + i;
+  	      if(g_prior[ij] != 0.0 && g_prior[ij] != 1.0)
+  	      {
 	            index_row[ counter ] = i;
 	            index_col[ counter ] = j;
 	            counter++;
@@ -225,9 +225,9 @@ void gcgm_DMH_bdmcmc_map( int *iter, int *burnin, int G[], double g_prior[], dou
 	for( j = 1; j < dim; j++ )
 	    for( i = 0; i < j; i++ )
 	    {
-	        ij = g_prior[ j * dim + i ];
-	        if( ( ij != 0.0 ) or ( ij != 1.0 ) )
-	        {
+  	      ij = j * dim + i;
+  	      if(g_prior[ij] != 0.0 && g_prior[ij] != 1.0)
+  	      {
 	            index_row[ counter ] = i;
 	            index_col[ counter ] = j;
 	            counter++;
@@ -397,9 +397,9 @@ void gcgm_DMH_bdmcmc_ma_multi_update( int *iter, int *burnin, int G[], double g_
 	for( j = 1; j < dim; j++ )
 	    for( i = 0; i < j; i++ )
 	    {
-	        ij = g_prior[ j * dim + i ];
-	        if( ( ij != 0.0 ) or ( ij != 1.0 ) )
-	        {
+  	      ij = j * dim + i;
+  	      if(g_prior[ij] != 0.0 && g_prior[ij] != 1.0)
+  	      {
 	            index_row[ counter ] = i;
 	            index_col[ counter ] = j;
 	            counter++;
@@ -555,9 +555,9 @@ void gcgm_DMH_bdmcmc_map_multi_update( int *iter, int *burnin, int G[], double g
 	for( j = 1; j < dim; j++ )
 	    for( i = 0; i < j; i++ )
 	    {
-	        ij = g_prior[ j * dim + i ];
-	        if( ( ij != 0.0 ) or ( ij != 1.0 ) )
-	        {
+  	      ij = j * dim + i;
+  	      if(g_prior[ij] != 0.0 && g_prior[ij] != 1.0)
+  	      {
 	            index_row[ counter ] = i;
 	            index_col[ counter ] = j;
 	            counter++;
@@ -744,9 +744,9 @@ void gcgm_DMH_rjmcmc_ma( int *iter, int *burnin, int G[], double g_prior[], doub
 	for( j = 1; j < dim; j++ )
 	    for( i = 0; i < j; i++ )
 	    {
-	        ij = g_prior[ j * dim + i ];
-	        if( ( ij != 0.0 ) or ( ij != 1.0 ) )
-	        {
+  	      ij = j * dim + i;
+  	      if(g_prior[ij] != 0.0 && g_prior[ij] != 1.0)
+  	      {
 	            index_row[ counter ] = i;
 	            index_col[ counter ] = j;
 	            counter++;
@@ -929,9 +929,9 @@ void gcgm_DMH_rjmcmc_map( int *iter, int *burnin, int G[], double g_prior[], dou
 	for( j = 1; j < dim; j++ )
 	    for( i = 0; i < j; i++ )
 	    {
-	        ij = g_prior[ j * dim + i ];
-	        if( ( ij != 0.0 ) or ( ij != 1.0 ) )
-	        {
+  	      ij = j * dim + i;
+  	      if(g_prior[ij] != 0.0 && g_prior[ij] != 1.0)
+  	      {
 	            index_row[ counter ] = i;
 	            index_col[ counter ] = j;
 	            counter++;
